==> wallaroo-2023.4.0b2-py3-none-any.whl: wallaroo/wallaroo_ml_ops_api_client/models/assays_list_response_200_item_baseline_type_1.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
  from ..models.assays_list_response_200_item_baseline_type_1_static import \
      AssaysListResponse200ItemBaselineType1Static





T = TypeVar("T", bound="AssaysListResponse200ItemBaselineType1")


@attr.s(auto_attribs=True)
class AssaysListResponse200ItemBaselineType1:
    """ 
        Attributes:
            static (AssaysListResponse200ItemBaselineType1Static):  Result from summarizing one sample collection.
     """

    static: 'AssaysListResponse200ItemBaselineType1Static'
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)


    def to_dict(self) -> Dict[str, Any]:
        static = self.static.to_dict()


        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "static": static,
        })

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.assays_list_response_200_item_baseline_type_1_static import \
            AssaysListResponse200ItemBaselineType1Static
        d = src_dict.copy()
        static = AssaysListResponse200ItemBaselineType1Static.from_dict(d.pop("static"))




        assays_list_response_200_item_baseline_type_1 = cls(
            static=static,
        )

        assays_list_response_200_item_baseline_type_1.additional_properties = d
        return assays_list_response_200_item_baseline_type_1

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> wallaroo-2024.2.0b2-py3-none-any.whl: wallaroo/wallaroo_ml_ops_api_client/models/assays_list_response_200_item_baseline_type_1.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.assays_list_response_200_item_baseline_type_1_static import (
        AssaysListResponse200ItemBaselineType1Static,
    )


T = TypeVar("T", bound="AssaysListResponse200ItemBaselineType1")


@_attrs_define
class AssaysListResponse200ItemBaselineType1:
    """
    Attributes:
        static (AssaysListResponse200ItemBaselineType1Static):  Result from summarizing one sample collection.
    """

    static: "AssaysListResponse200ItemBaselineType1Static"
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        static = self.static.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "static": static,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.assays_list_response_200_item_baseline_type_1_static import (
            AssaysListResponse200ItemBaselineType1Static,
        )

        d = src_dict.copy()
        static = AssaysListResponse200ItemBaselineType1Static.from_dict(d.pop("static"))

        assays_list_response_200_item_baseline_type_1 = cls(
            static=static,
        )

        assays_list_response_200_item_baseline_type_1.additional_properties = d
        return assays_list_response_200_item_baseline_type_1

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
